@@ -1,6 +1,11 @@
+
+# seconds per test
+my $seconds = $ARGV[0] || 2;
+
+#------------------------------------------------------------------------------
+use blib;
 use strict;
 use warnings;
-use File::Temp ();
 use Benchmark qw(:hireswallclock cmpthese countit);
 use UUID qw(
     generate_v1 generate_v3 generate_v4 generate_v5 generate_v6 generate_v7
@@ -8,8 +13,6 @@ use UUID qw(
     unparse
 );
 
-my $seconds = $ARGV[0] || 1;
-
 print "\ncomparing calling styles...\n\n";
 
 my $r = cmpthese({
